@@ -1,6 +1,6 @@
 #coding: utf-8
 
-__version__ = '0.5.0'
+__version__ = '0.5.1'
 __author__ = u'Marek Waluś <marekwalus@gmail.com>'
 
 
@@ -32,10 +32,15 @@ class Route(object):
         Initialize route
 
         :param method: Method name: `GET`, `OPTIONS`, `POST`, `PUT`, `PATCH` or `DELETE`
+        :type method: str
         :param url: Route url, may be python string template if path parameters are defined in `params`
+        :type url: str
         :param params: List of route parameters, :class Param: instances
-        :param request_kwargs:  Arguments as dict for request instance, override service `request_globals`
-        :param session_kwargs: Arguments as dict for session instance. override service `session_globals`
+        :type params: list
+        :param request_kwargs: Keyword arguments for request instance, override service `request_globals`
+        :type request_kwargs: dict
+        :param session_kwargs: Keyword arguments for session instance. override service `session_globals`
+        :type session_kwargs: dict
         """
         assert method in AVAILABLE_METHODS, \
             'Unrecognized method: %s' % method
@@ -43,14 +48,14 @@ class Route(object):
         self.method = method
         self.url = url
         self.params = dict((param.value, param) for param in params)
-        self.request_kwargs = request_kwargs if request_kwargs else {}
-        self.session_kwargs = session_kwargs if session_kwargs else {}
+        self.request_kwargs = request_kwargs or {}
+        self.session_kwargs = session_kwargs or {}
 
     def __call__(self, **kwargs):
         """
         Prepare data and start request
 
-        :kwargs: keyword arguments
+        :param kwargs: route parameters
         """
         # Check if all keyword arguments are defined in route
         for name, value in kwargs.iteritems():
@@ -74,6 +79,10 @@ class Route(object):
                 if isinstance(self.params[name], cls):
                     groups[cls_name].update({name: value})
 
+	# If just one data param is defined create as main data
+	if groups['DataParam'].keys() == 1:
+		groups['DataParam'] = groups['DataParam'].keys()[0]
+
         # Create Session and Request instance
         session = Session()
         request = Request(
@@ -130,4 +139,4 @@ class Service(object):
         # Add service reference to all routes
         for name, route in self.routes:
             route.service = self
-            route.name = name
\ No newline at end of file
+            route.name = name
